Engine configuration module. Is used to create a new engine configuration.
Engine configuration module
This module contains the configuration for the simulation engine. It includes the input parameters for the simulation and the builder to create the configuration.
Structs
- Simulation
Options - Input parameters for a simulation.
- Simulation
Options Builder - Builder for creating a new simulation options.
Enums
- Valuation
Model - Valuation model for the token.