Module engine_config

Module engine_config 

Engine configuration module. Is used to create a new engine configuration.

Engine configuration module

This module contains the configuration for the simulation engine. It includes the input parameters for the simulation and the builder to create the configuration.

Structs

SimulationOptions
Input parameters for a simulation.
SimulationOptionsBuilder
Builder for creating a new simulation options.

Enums

ValuationModel
Valuation model for the token.